Documentation
¶
Overview ¶
Copyright © 2020 NAME HERE <EMAIL ADDRESS>
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- Variables
- func AddHCLCtxOption(option HCLCtxOption)
- func CheckIfErr(err error)
- func CreateDeployer(env string) (deployer.Deployer, error)
- func Execute()
- func GetDeployerCfg() *config.Config
- func GetEnvironment(env string) *config.Environment
- func GetInputEnv() string
- func GetVarFiles(workingDir string) (vars []string, err error)
- func RegisterCommand(c *cobra.Command)
- type HCLCtxOption
Constants ¶
This section is empty.
Variables ¶
var (
ErrEnvironmentNotFound = errors.New("environment not found")
)
var (
Version = "undefined"
)
Functions ¶
func AddHCLCtxOption ¶
func AddHCLCtxOption(option HCLCtxOption)
func CheckIfErr ¶
func CheckIfErr(err error)
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func GetDeployerCfg ¶
func GetEnvironment ¶
func GetEnvironment(env string) *config.Environment
func GetInputEnv ¶
func GetInputEnv() string
func GetVarFiles ¶
func RegisterCommand ¶
Types ¶
type HCLCtxOption ¶
type HCLCtxOption interface {
Apply(ctx *hcl.EvalContext)
}